@@ -7,35 +7,33 @@ from typing import Iterable, Tuple
 import click
 import yaml
 
-from . import git
+from .component import Component
+from .gitrepo import GitRepo, GitCommandError
 from .helpers import ApiError, rm_tree_contents, lieutenant_query, sliding_window
 from .cluster import Cluster
 from .config import Config, Migration
 from .k8sobject import K8sObject
 
 
-def fetch_customer_catalog(config: Config, cluster: Cluster):
+def fetch_catalog(config: Config, cluster: Cluster) -> GitRepo:
     click.secho("Updating cluster catalog...", bold=True)
     repo_url = cluster.catalog_repo_url
     if config.debug:
         click.echo(f" > Cloning cluster catalog {repo_url}")
-    return git.clone_repository(repo_url, config.catalog_dir, config)
+    return GitRepo.clone(repo_url, config.catalog_dir, config)
 
 
-def _pretty_print_component_commit(name, component):
-    repo = component.repo
-    sha = repo.head.commit.hexsha
-    short_sha = repo.git.rev_parse(sha, short=6)
+def _pretty_print_component_commit(name, component: Component) -> str:
+    short_sha = component.repo.head_short_sha
     return f" * {name}: {component.version} ({short_sha})"
 
 
-def _pretty_print_config_commit(name, repo):
-    sha = repo.head.commit.hexsha
-    short_sha = repo.git.rev_parse(sha, short=6)
+def _pretty_print_config_commit(name, repo: GitRepo) -> str:
+    short_sha = repo.head_short_sha
     return f" * {name}: {short_sha}"
 
 
-def _render_catalog_commit_msg(cfg):
+def _render_catalog_commit_msg(cfg) -> str:
     # pylint: disable=import-outside-toplevel
     import datetime
 
@@ -44,26 +42,29 @@ def _render_catalog_commit_msg(cfg):
     component_commits = [
         _pretty_print_component_commit(cn, c) for cn, c in cfg.get_components().items()
     ]
-    component_commits = "\n".join(component_commits)
+    component_commits_str = "\n".join(component_commits)
 
     config_commits = [
         _pretty_print_config_commit(c, r) for c, r in cfg.get_configs().items()
     ]
-    config_commits = "\n".join(config_commits)
+    config_commits_str = "\n".join(config_commits)
 
     return f"""Automated catalog update from Commodore
 
 Component commits:
-{component_commits}
+{component_commits_str}
 
 Configuration commits:
-{config_commits}
+{config_commits_str}
 
 Compilation timestamp: {now}
 """
 
 
-def clean_catalog(repo):
+def clean_catalog(repo: GitRepo):
+    if repo.working_tree_dir is None:
+        raise click.ClickException("Catalog repo has no working tree")
+
     catalogdir = P(repo.working_tree_dir, "manifests")
     click.secho("Cleaning catalog repository...", bold=True)
     # delete everything in catalog
@@ -74,7 +75,7 @@ def clean_catalog(repo):
         rm_tree_contents(repo.working_tree_dir)
 
 
-def _push_catalog(cfg: Config, repo, commit_message):
+def _push_catalog(cfg: Config, repo: GitRepo, commit_message: str):
     """Push catalog to catalog repo if conditions to allow push are met.
 
     Conditions to allow pushing are:
@@ -89,11 +90,11 @@ def _push_catalog(cfg: Config, repo, commit_message):
 
         if cfg.push:
             click.echo(" > Commiting changes...")
-            git.commit(repo, commit_message, cfg)
+            repo.commit(commit_message)
             click.echo(" > Pushing catalog to remote...")
             try:
-                pushinfos = repo.remotes.origin.push()
-            except git.GitCommandError as e:
+                pushinfos = repo.push()
+            except GitCommandError as e:
                 raise click.ClickException(
                     "Failed to push to the catalog repository: "
                     + f"Git exited with status code {e.status}"
@@ -113,7 +114,7 @@ def _push_catalog(cfg: Config, repo, commit_message):
                 " > Add flag --interactive to show the diff and decide on the push"
             )
     else:
-        repo.head.reset(working_tree=False)
+        repo.reset(working_tree=False)
         click.echo(" > Skipping commit+push to catalog in local mode...")
 
 
@@ -188,7 +189,10 @@ def _kapitan_029_030_difffunc(
     return diff_lines, suppress_diff
 
 
-def update_catalog(cfg: Config, targets: Iterable[str], repo):
+def update_catalog(cfg: Config, targets: Iterable[str], repo: GitRepo):
+    if repo.working_tree_dir is None:
+        raise click.ClickException("Catalog repo has no working tree")
+
     click.secho("Updating catalog repository...", bold=True)
     # pylint: disable=import-outside-toplevel
     from distutils import dir_util
@@ -201,9 +205,9 @@ def update_catalog(cfg: Config, targets: Iterable[str], repo):
     start = time.time()
     if cfg.migration == Migration.KAP_029_030:
         click.echo(" > Smart diffing started... (this can take a while)")
-        difftext, changed = git.stage_all(repo, diff_func=_kapitan_029_030_difffunc)
+        difftext, changed = repo.stage_all(diff_func=_kapitan_029_030_difffunc)
     else:
-        difftext, changed = git.stage_all(repo)
+        difftext, changed = repo.stage_all()
     elapsed = time.time() - start
 
     if changed:
