@@ -1,6 +1,7 @@
 import json
+import sys
 from pathlib import Path
-from typing import Iterable
+from typing import Iterable, Optional, Tuple
 
 import click
 import yaml
@@ -15,6 +16,7 @@ from .component.template import ComponentTemplater
 from .component.compile import compile_component
 from .inventory.render import extract_components
 from .inventory.parameters import InventoryFacts
+from .inventory.lint_components import lint_components
 
 pass_config = click.make_pass_decorator(Config)
 
@@ -377,7 +379,7 @@ def inventory(config: Config, verbose):
         + "Can be repeated."
     ),
     multiple=True,
-    type=click.Path(exists=True, file_okay=True, dir_okay=False, path_type=Path),
+    type=click.Path(exists=True, file_okay=True, dir_okay=False),
 )
 @click.option(
     " / -A",
@@ -386,6 +388,7 @@ def inventory(config: Config, verbose):
     help="Whether to allow missing classes when rendering the inventory. Defaults to true.",
 )
 @click.argument("global-config")
+@click.argument("tenant-config", required=False)
 @verbosity
 @pass_config
 # pylint: disable=too-many-arguments
@@ -393,15 +396,19 @@ def component_versions(
     config: Config,
     verbose,
     global_config: str,
+    tenant_config: Optional[str],
     output_format: str,
-    values: Iterable[Path],
+    values: Iterable[str],
     allow_missing_classes: bool,
 ):
     config.update_verbosity(verbose)
+    extra_values = [Path(v) for v in values]
     try:
         components = extract_components(
             config,
-            InventoryFacts(global_config, None, values, allow_missing_classes),
+            InventoryFacts(
+                global_config, tenant_config, extra_values, allow_missing_classes
+            ),
         )
     except ValueError as e:
         raise click.ClickException(f"While extracting components: {e}") from e
@@ -412,6 +419,42 @@ def component_versions(
         click.echo(yaml.safe_dump(components))
 
 
+@inventory.command(
+    name="lint",
+    short_help="Lint YAML files for Commodore inventory structures in the provided paths",
+    no_args_is_help=True,
+)
+@click.argument(
+    "target", type=click.Path(file_okay=True, dir_okay=True, exists=True), nargs=-1
+)
+@verbosity
+@pass_config
+def inventory_lint(config: Config, verbose: int, target: Tuple[str]):
+    """Lint YAML files in the provided paths.
+
+    The command assumes that any YAML file found in the provided paths is part of a
+    Commodore inventory structure."""
+    config.update_verbosity(verbose)
+
+    if len(target) == 0:
+        click.secho("> No files provided, exiting...", fg="yellow")
+        sys.exit(2)
+
+    error_counts = []
+    for t in target:
+        lint_target = Path(t)
+        error_counts.append(lint_components(config, lint_target))
+
+    errors = sum(error_counts)
+    exit_status = 0 if errors == 0 else 1
+    if errors == 0:
+        click.secho("No errors 🎉 ✨", bold=True)
+    if errors > 0:
+        click.secho(f"Found {errors} errors", bold=True)
+
+    sys.exit(exit_status)
+
+
 def main():
     load_dotenv(dotenv_path=find_dotenv(usecwd=True))
     commodore.main(prog_name="commodore", auto_envvar_prefix="COMMODORE")
